BreadcrumbLogger class final
A Logger that adds a Sentry Breadcrumb for each log message.
This logger will add breadcrumbs of type debug, whose level corresponds to
a Couchbase Lite LogLevel.
The LogDomain is used to build the category of the breadcrumb by prefixing
it with cbl.. For example, full category for a log message from the
LogDomain.database domain is cbl.database.
Constructors
- BreadcrumbLogger({LogLevel? level, Hub? hub})
-
Creates a
Loggerthat adds a SentryBreadcrumbfor each log message.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ LogLevel
-
The minimum log level for which
logwill be called.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
log(
LogLevel level, LogDomain domain, String message) → void - The callback which is invoked for each log message.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited